@@ -18,7 +18,6 @@ char *fake = N_("Tolerance for InfiniteSum and InfiniteProduct");
 char *fake = N_("Absolute value");
 char *fake = N_("Replace very small number with zero");
 char *fake = N_("Return the fractional part of a number");
-char *fake = N_("Division w/o remainder");
 char *fake = N_("Return the sign (-1,0,1)");
 char *fake = N_("Logarithm of any base (calls DiscreteLog if in modulo mode), if base is not given, e is used");
 char *fake = N_("The arccos (inverse cos) function");
@@ -64,7 +63,7 @@ char *fake = N_("Test if Mp is a Mersenne prime using the Lucas-Lehmer test");
 char *fake = N_("Return all maximal prime power factors of a number");
 char *fake = N_("Vector with the known Mersenne prime exponents");
 char *fake = N_("Return the Moebius mu function evaluated in n");
-char *fake = N_("Returns the padic valuation (number of trailing zeros in base p).");
+char *fake = N_("Returns the p-adic valuation (number of trailing zeros in base p).");
 char *fake = N_("Compute a^b mod m");
 char *fake = N_("Return all prime factors of a number");
 char *fake = N_("Pseudoprime test, true iff b^(n-1) == 1 (mod n)");
@@ -74,7 +73,7 @@ char *fake = N_("Find square root of n mod p (a prime). Null is returned if not
 char *fake = N_("Apply a function over all entries of a matrix and return a matrix of the results");
 char *fake = N_("Apply a function over all entries of 2 matrices (or 1 value and 1 matrix) and return a matrix of the results");
 char *fake = N_("Remove column(s) and row(s) from a matrix");
-char *fake = N_("Calculate the kth compund matrix of A");
+char *fake = N_("Calculate the kth compound matrix of A");
 char *fake = N_("Delete a column of a matrix");
 char *fake = N_("Delete a row of a matrix");
 char *fake = N_("Get the dot product of two vectors (no conjugates)");
@@ -88,12 +87,13 @@ char *fake = N_("Get the outer product of two vectors");
 char *fake = N_("Reverse elements in a vector");
 char *fake = N_("Calculate sum of each row in a matrix");
 char *fake = N_("Calculate sum of squares of each row in a matrix");
+char *fake = N_("Shuffle elements in a vector");
 char *fake = N_("Sort vector elements");
 char *fake = N_("Removes any all-zero rows of M");
 char *fake = N_("Return column(s) and row(s) from a matrix");
 char *fake = N_("Swap two rows in a matrix");
 char *fake = N_("Zero out entries below the diagonal");
-char *fake = N_("Get the auxilliary unit matrix of size n");
+char *fake = N_("Get the auxiliary unit matrix of size n");
 char *fake = N_("Evaluate (v,w) with respect to the bilinear form given by the matrix A");
 char *fake = N_("Return a function that evaluates two vectors with respect to the bilinear form given by A");
 char *fake = N_("Get the characteristic polynomial as a vector");
@@ -110,21 +110,21 @@ char *fake = N_("Direct sum of matrices");
 char *fake = N_("Direct sum of a vector of matrices");
 char *fake = N_("Get the eigenvalues of a matrix (Currently only for up to 4x4 or triangular matrices)");
 char *fake = N_("Get the eigenvalues and eigenvectors of a matrix (Currently only for up to 2x2 matrices)");
-char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use hermitian product)");
+char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use Hermitian product)");
 char *fake = N_("Hankel matrix");
 char *fake = N_("Hilbert matrix of order n");
 char *fake = N_("Get the image (columnspace) of a linear transform");
 char *fake = N_("Get the Inf Norm of a vector");
 char *fake = N_("Get the invariant factors of a square integer matrix (not its characteristic)");
 char *fake = N_("Inverse Hilbert matrix of order n");
-char *fake = N_("Is a matrix hermitian");
+char *fake = N_("Is a matrix Hermitian");
 char *fake = N_("Test if a vector is in a subspace");
 char *fake = N_("Is a matrix (or number) invertible (Integer matrix is invertible iff it's invertible over the integers)");
 char *fake = N_("Is a matrix (or number) invertible over a field");
 char *fake = N_("Is a matrix normal");
 char *fake = N_("Is a matrix positive definite");
 char *fake = N_("Is a matrix positive semidefinite");
-char *fake = N_("Is a matrix skew-hermitian");
+char *fake = N_("Is a matrix skew-Hermitian");
 char *fake = N_("Is a matrix unitary");
 char *fake = N_("Get the jordan block corresponding to lambda and n");
 char *fake = N_("Get the kernel (nullspace) of a linear transform");
@@ -134,7 +134,7 @@ char *fake = N_("Return the columns that are not the pivot columns of a matrix")
 char *fake = N_("Get the p Norm (or 2 Norm if no p is supplied) of a vector");
 char *fake = N_("Get the nullity of a matrix");
 char *fake = N_("Get the orthogonal complement of the columnspace");
-char *fake = N_("Projection of vector v onto subspace W given a sesquilinear form B (if not given use hermitian product)");
+char *fake = N_("Projection of vector v onto subspace W given a sesquilinear form B (if not given use Hermitian product)");
 char *fake = N_("Get the QR decomposition of A, returns R and Q can be a reference");
 char *fake = N_("Get the rank of a matrix");
 char *fake = N_("Return the Rayleigh quotient of a matrix and a vector");
@@ -180,6 +180,8 @@ char *fake = N_("Calculate the nth triangular number");
 char *fake = N_("Calculate permutations");
 char *fake = N_("Integration of f by Composite Simpson's Rule on the interval [a,b] with the number of steps calculated by the fourth derivative bound and the desired tolerance");
 char *fake = N_("Attempt to calculate derivative by trying first symbolically and then numerically");
+char *fake = N_("Return a function which is the even periodic extension of f defined on the interval [0,L]");
+char *fake = N_("Return a function which is a Fourier series with the coefficients given by the vectors a (sines) and b (cosines).  Note that a@(1) is the constant coefficient!");
 char *fake = N_("Try to calculate an infinite product for a single parameter function");
 char *fake = N_("Try to calculate an infinite product for a double parameter function with func(arg,n)");
 char *fake = N_("Try to calculate an infinite sum for a single parameter function");
@@ -190,12 +192,20 @@ char *fake = N_("Calculate the left limit of a real-valued function at x0");
 char *fake = N_("Calculate the limit of a real-valued function at x0.  Tries to calculate both left and right limits.");
 char *fake = N_("Integration by midpoint rule");
 char *fake = N_("Attempt to calculate numerical derivative");
+char *fake = N_("Numerically compute the coefficients for a cosine Fourier series for a function on [0,L] up to the Nth coefficient.");
+char *fake = N_("Return a function which is the Fourier cosine series of f on [0,L] with coefficients up to N computed numerically");
+char *fake = N_("Numerically compute the coefficients for a Fourier series with half-period L up to the Nth coefficient.");
+char *fake = N_("Return a function which is the Fourier series of f with half-period L with coefficients up to N computed numerically");
+char *fake = N_("Numerically compute the coefficients for a sine Fourier series for a function on [0,L] up to the Nth coefficient.");
+char *fake = N_("Return a function which is the Fourier sine series of f on [0,L] with coefficients up to N computed numerically");
 char *fake = N_("Integration by rule set in NumericalIntegralFunction of f from a to b using NumericalIntegralSteps steps");
 char *fake = N_("Attempt to calculate numerical left derivative");
 char *fake = N_("Attempt to calculate the limit of f(step_fun(i)) as i goes from 1 to N");
 char *fake = N_("Attempt to calculate numerical right derivative");
+char *fake = N_("Return a function which is the odd periodic extension of f defined on the interval [0,L]");
 char *fake = N_("Compute one-sided derivative using five point formula");
 char *fake = N_("Compute one-sided derivative using three-point formula");
+char *fake = N_("Return a function which is the periodic extension of f defined on the interval [a,b]");
 char *fake = N_("Calculate the right limit of a real-valued function at x0");
 char *fake = N_("Compute two-sided derivative using five-point formula");
 char *fake = N_("Compute two-sided derivative using three-point formula");
@@ -219,6 +229,7 @@ char *fake = N_("Convert degrees to radians");
 char *fake = N_("Convert radians to degrees");
 char *fake = N_("Find roots of a cubic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
+char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns an n+1 by 2 matrix of values");
 char *fake = N_("Find root of a function using the bisection method");
 char *fake = N_("Find root of a function using the method of false position");
 char *fake = N_("Find root of a function using the Muller's method");
@@ -226,6 +237,7 @@ char *fake = N_("Find root of a function using the secant method");
 char *fake = N_("Find roots of a polynomial (given as vector of coefficients)");
 char *fake = N_("Find roots of a quartic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
+char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns an n+1 by 2 matrix of values");
 char *fake = N_("Calculate average of an entire matrix");
 char *fake = N_("Integral of the GaussFunction from 0 to x (area under the normal curve)");
 char *fake = N_("The normalized Gauss distribution function (the normal curve)");
