@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2009 George Lebl
+ * Copyright (C) 1997-2011 George Lebl
  *
  * Author: George Lebl
  *
@@ -32,51 +32,64 @@
 #include "matrix.h"
 #include "matrixw.h"
 
+#include <vicious.h>
+
 #include "compil.h"
 
-/*sort of weird encoding, use 'a'+upper 4 bits and 'a'+lower 4 bits*/
-static void
-append_string (GString *gs,const char *s)
-{
-	const char *p;
-	char out[3]="aa";
-	for(p=s;*p;p++) {
-		out[0]='a'+((*p)&0xF);
-		out[1]='a'+((*p)>>4);
-		g_string_append(gs,out);
-	}
-}
-
-/*sort of weird encoding, use 'a'+upper 4 bits and 'a'+lower 4 bits*/
+/* first char 'A' then rest just ascii */
+/* first char 'B' then rest Base64 */
+/* first char 'E' then empty */
 char *
 gel_decode_string (const char *s)
 {
-	int len = strlen(s);
-	const char *ps;
-	char *p,*pp;
-	if(len%2 == 1)
+	if (s == NULL)
 		return NULL;
-	
-	/*the 0 takes care of the termination*/
-	p = g_new0(char,(len/2)+1);
-	
-	for(ps=s,pp=p;*ps;ps+=2,pp++) {
-		if(*ps<'a' || *ps >'a'+0xF ||
-		   *(ps+1)<'a' || *(ps+1) >'a'+0xF) {
-			g_free(p);
+	if (s[0] == 'A') {
+		return g_strdup (&(s[1]));
+	} else if (s[0] == 'B') {
+		gsize len;
+		char *p = (char *)g_base64_decode (&(s[1]), &len);
+		if (p == NULL || len < 0) /* error was probably logged by now */
 			return NULL;
-		}
-		*pp = (*ps-'a') + ((*(ps+1)-'a')<<4);
+		p = g_realloc (p, len+1);
+		p[len] = '\0';
+		return p;
+	} else if (s[0] == 'E') {
+		return g_strdup ("");
+	} else {
+		g_warning ("gel_decode_string: bad string!");
+		return NULL;
 	}
-	return p;
+}
+
+static int
+is_ok_ascii (const char *s)
+{
+	const char *p;
+	for (p = s; *p != '\0'; p++) {
+		if ( ! ( (*p >= 'a' && *p <= 'z') ||
+			 (*p >= 'A' && *p <= 'Z') ||
+			 (*p >= '0' && *p <= '9') ||
+			 strchr ("():,.[] !?~+-_{}/=><*^'\"", *p) != NULL) ) {
+			return FALSE;
+		}
+	}
+	return TRUE;
 }
 
 char *
 gel_encode_string (const char *s)
 {
-	GString *gs = g_string_new (NULL);
-	append_string (gs, s);
-	return g_string_free (gs, FALSE);
+	if (ve_string_empty (s))
+		return g_strdup ("E");
+	if (is_ok_ascii (s)) {
+		return g_strconcat ("A", s, NULL);
+	} else {
+		char *p = g_base64_encode ((const unsigned char *)s, strlen (s));
+		char *ret = g_strconcat ("B", p, NULL);
+		g_free (p);
+		return ret;
+	}
 }
 
 static void
@@ -126,24 +139,47 @@ gel_compile_node(GelETree *t,GString *gs)
 		g_string_append_printf (gs, ";%s", t->id.id->token);
 		break;
 	case GEL_STRING_NODE:
-		if(*t->str.str) {
-			g_string_append_c(gs,';');
-			append_string(gs,t->str.str);
-		} else {
-			g_string_append(gs,";E");
-		}
+		g_string_append_c (gs, ';');
+		s = gel_encode_string (t->str.str);
+		g_string_append (gs, s);
+		g_free (s);
 		break;
 	case GEL_FUNCTION_NODE:
 		g_assert(t->func.func->type==GEL_USER_FUNC);
 		/*g_assert(t->func.func->id==NULL);*/
-		g_string_append_printf (gs, ";%s;%s;%d;%d;%d;%d",
+		g_string_append_printf (gs,
+					";%s;%s;n%d;v%d;p%d;o%d;l%d;e%d;b%d",
 					t->func.func->id ? t->func.func->id->token : "*",
 					t->func.func->symbolic_id ? t->func.func->symbolic_id->token : "*",
 					t->func.func->nargs,
 					t->func.func->vararg,
 					t->func.func->propagate_mod,
-					t->func.func->no_mod_all_args);
-		for(li=t->func.func->named_args;li;li=g_slist_next(li)) {
+					t->func.func->no_mod_all_args,
+					t->func.func->local_all,
+					t->func.func->never_on_subst_list,
+					t->func.func->built_subst_dict);
+		/* Make sure to also update calc compile_funcs_in_dict
+		 * and related! */
+
+		if (t->func.func->local_idents == NULL)
+			g_string_append (gs, ";-");
+		for (li = t->func.func->local_idents; li != NULL; li = li->next) {
+			GelToken *tok = li->data;
+			if (li != t->func.func->local_idents)
+				g_string_append_printf (gs, ",%s", tok->token);
+			else
+				g_string_append_printf (gs, ";%s", tok->token);
+		}
+		if (t->func.func->subst_dict == NULL)
+			g_string_append (gs, ";-");
+		for (li = t->func.func->subst_dict; li != NULL; li = li->next) {
+			GelToken *tok = li->data;
+			if (li != t->func.func->subst_dict)
+				g_string_append_printf (gs, ",%s", tok->token);
+			else
+				g_string_append_printf (gs, ";%s", tok->token);
+		}
+		for (li = t->func.func->named_args; li != NULL; li = li->next) {
 			GelToken *tok = li->data;
 			g_string_append_printf (gs, ";%s", tok->token);
 		}
@@ -194,6 +230,9 @@ gel_decompile_node(char **ptrptr)
 	int vararg = -1;
 	int propagate_mod = -1;
 	int no_mod_all_args = -1;
+	int local_all = -1;
+	int never_on_subst_list = -1;
+	int built_subst_dict = -1;
 	int quote;
 	int oper;
 	int i,j;
@@ -201,7 +240,7 @@ gel_decompile_node(char **ptrptr)
 	GelMatrixW *m;
 	GelETree *li = NULL;
 	GelETree *args;
-	GSList *oli;
+	GSList *oli, *local_idents, *subst_dict;
 	GelEFunc *func;
 	mpw_t tmp;
 
@@ -339,29 +378,69 @@ gel_decompile_node(char **ptrptr)
 		p = strtok_r (NULL,";", ptrptr);
 		if G_UNLIKELY (!p) return NULL;
 		nargs = -1;
-		sscanf(p,"%d",&nargs);
+		sscanf(p,"n%d",&nargs);
 		if G_UNLIKELY (nargs==-1) return NULL;
 
 		p = strtok_r (NULL,";", ptrptr);
 		if G_UNLIKELY (!p) return NULL;
-		sscanf(p,"%d",&vararg);
+		sscanf(p,"v%d",&vararg);
 		if G_UNLIKELY (vararg == -1) return NULL;
 
 		p = strtok_r (NULL,";", ptrptr);
 		if G_UNLIKELY (!p) return NULL;
-		sscanf(p,"%d",&propagate_mod);
+		sscanf(p,"p%d",&propagate_mod);
 		if G_UNLIKELY (propagate_mod == -1) return NULL;
 
 		p = strtok_r (NULL,";", ptrptr);
 		if G_UNLIKELY (!p) return NULL;
-		sscanf(p,"%d",&no_mod_all_args);
+		sscanf(p,"o%d",&no_mod_all_args);
 		if G_UNLIKELY (no_mod_all_args == -1) return NULL;
 
+		p = strtok_r (NULL,";", ptrptr);
+		if G_UNLIKELY (p == NULL) return NULL;
+		sscanf(p,"l%d",&local_all);
+		if G_UNLIKELY (local_all == -1) return NULL;
+
+		p = strtok_r (NULL,";", ptrptr);
+		if G_UNLIKELY (p == NULL) return NULL;
+		sscanf(p,"e%d",&never_on_subst_list);
+		if G_UNLIKELY (never_on_subst_list == -1) return NULL;
+
+		p = strtok_r (NULL,";", ptrptr);
+		if G_UNLIKELY (p == NULL) return NULL;
+		sscanf(p,"b%d",&built_subst_dict);
+		if G_UNLIKELY (built_subst_dict == -1) return NULL;
+
+		p = strtok_r (NULL,";", ptrptr);
+		if G_UNLIKELY (p == NULL) return NULL;
+		local_idents = NULL;
+		if (strcmp (p, "-") != 0) {
+			char **s;
+			s = g_strsplit (p, ",", -1);
+			for (i = 0; s[i] != NULL; i++) {
+				local_idents = g_slist_append (local_idents, d_intern (s[i]));
+			}
+			g_strfreev (s);
+		}
+
+		p = strtok_r (NULL,";", ptrptr);
+		if G_UNLIKELY (p == NULL) return NULL;
+		subst_dict = NULL;
+		if (strcmp (p, "-") != 0) {
+			char **s;
+			s = g_strsplit (p, ",", -1);
+			for (i = 0; s[i] != NULL; i++) {
+				subst_dict = g_slist_append (subst_dict, d_intern (s[i]));
+			}
+			g_strfreev (s);
+		}
+
 		oli = NULL;
 		for(i=0;i<nargs;i++) {
 			p = strtok_r (NULL,";", ptrptr);
 			if G_UNLIKELY (!p) {
-				g_slist_free(oli);
+				g_slist_free (oli);
+				g_slist_free (local_idents);
 				return NULL;
 			}
 			oli = g_slist_append(oli,d_intern(p));
@@ -369,7 +448,8 @@ gel_decompile_node(char **ptrptr)
 		
 		n = gel_decompile_node (ptrptr);
 		if G_UNLIKELY (!n) {
-			g_slist_free(oli);
+			g_slist_free (oli);
+			g_slist_free (local_idents);
 			return NULL;
 		}
 
@@ -380,6 +460,11 @@ gel_decompile_node(char **ptrptr)
 		func->vararg = vararg ? 1 : 0;
 		func->propagate_mod = propagate_mod ? 1 : 0;
 		func->no_mod_all_args = no_mod_all_args ? 1 : 0;
+		func->local_all = local_all ? 1 : 0;
+		func->never_on_subst_list = never_on_subst_list ? 1 : 0;
+		func->built_subst_dict = built_subst_dict ? 1 : 0;
+		func->local_idents = local_idents;
+		func->subst_dict = subst_dict;
 
 		GEL_GET_NEW_NODE(n);
 		n->type = GEL_FUNCTION_NODE;
@@ -461,17 +546,17 @@ gel_decompile_tree (char *s)
 
 	if G_UNLIKELY (strcmp (p, "T") != 0) {
 		gel_errorout (_("Bad tree record when decompiling"));
+		g_free (s);
 		return NULL;
 	}
 	
 	t = gel_decompile_node (&ptrptr);
+	g_free (s);
+
 	if G_UNLIKELY (t == NULL) {
-		printf ("FOO!\n");
 		gel_errorout (_("Bad tree record when decompiling"));
 		return NULL;
 	}
 
-	g_free (s);
-	
 	return t;
 }
